summaryrefslogtreecommitdiff
path: root/usr.bin/cvs/repository.c
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/cvs/repository.c')
-rw-r--r--usr.bin/cvs/repository.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/usr.bin/cvs/repository.c b/usr.bin/cvs/repository.c
index 5f92673c806..25b11c917df 100644
--- a/usr.bin/cvs/repository.c
+++ b/usr.bin/cvs/repository.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: repository.c,v 1.9 2007/01/25 18:56:33 otto Exp $ */
+/* $OpenBSD: repository.c,v 1.10 2007/02/07 23:47:56 todd Exp $ */
/*
* Copyright (c) 2006 Joris Vink <joris@openbsd.org>
*
@@ -119,10 +119,10 @@ cvs_repository_getdir(const char *dir, const char *wdir,
/*
* nfs and afs will show d_type as DT_UNKNOWN
* for files and/or directories so when we encounter
* this we call stat() on the path to be sure.
*/
if (dp->d_type == DT_UNKNOWN) {
- if (stat(rpath, &st) == -1)
+ if (lstat(rpath, &st) == -1)
fatal("'%s': %s", rpath, strerror(errno));
switch (st.st_mode & S_IFMT) {
@@ -119,10 +119,10 @@ cvs_repository_getdir(const char *dir, const char *wdir,
* nfs and afs will show d_type as DT_UNKNOWN
* for files and/or directories so when we encounter
- * this we call stat() on the path to be sure.
+ * this we call lstat() on the path to be sure.
*/
if (dp->d_type == DT_UNKNOWN) {